abacusai.web_search_response — AbacusAI documentation

# abacusai.web_search_response

## Classes

`AbstractApiClass` |
`WebSearchResult` | A single search result.
`WebSearchResponse` | Result of running a web search with optional content fetching.

## Module Contents

class abacusai.web_search_response.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.web_search_response.WebSearchResult(client, title=None, url=None, snippet=None, content=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A single search result.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - title (str) – The title of the search result.

    - url (str) – The URL of the search result.

    - snippet (str) – The snippet of the search result.

    - content (str) – The page of content fetched from the url.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.web_search_response.WebSearchResponse(client, searchResults={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Result of running a web search with optional content fetching.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - searchResults (WebSearchResult) – List of search results.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict